@@ -3,8 +3,17 @@ from discord.ext import commands
 import re
 from typing import List
 import json
+from emoji import UNICODE_EMOJI
 
-class Form(object):
+class FormResponse:
+    def __init__(self,data:dict) -> None:
+        for d in data.keys():
+            if isinstance(data[d], dict):
+                setattr(self,d,data[d]['res'])
+            else:
+                setattr(self,d,data[d])
+
+class Form:
     """The basic form object.
 
     Parameters:
@@ -57,11 +66,11 @@ class Form(object):
         question : str
             The question as a string that should be added.
 
-        key : str, optional
-            The prefered key to be used. If none, defaults to the to the question. By default None.
+        key : str
+            What the attribute containing the answer should be called.
 
         qtype : str, optional
-            The input validation to be used (incomplete), by default None
+            The input validation to be used, by default None
 
         Returns
         -------
@@ -78,11 +87,11 @@ class Form(object):
         if not key:
             key = question
         valid_qtypes = ['invite','channel','user','member','role','category']
-        dictionary = {'res':None,'type':None,'question':question}
+        dictionary = {'res':None,'question':question}
         if qtype:
+            dictionary['type'] = None
             if qtype.lower() not in valid_qtypes:
                 raise InvalidFormType(f"Type '{qtype}' is invalid!")
-
             dictionary['type'] = qtype
             self._tries = 3
 
@@ -133,7 +142,11 @@ class Form(object):
                 emoji = await commands.EmojiConverter().convert(self._ctx,answer)
                 return emoji
             except:
-                return False
+                try:
+                    assert emoji in UNICODE_EMOJI
+                except:
+                    return emoji
+                return True
         else:
             self._tries -= 1
             raise InvalidFormType(f"Type '{qtype}' is invalid!")
@@ -191,8 +204,7 @@ class Form(object):
             newclr = color.replace("#","")
             color = f"0x{newclr}"
         color = await commands.ColourConverter().convert(self._ctx,color)
-        self.color = color
-        return
+        self._color = color
 
     async def start(self,channel=None) -> dict:
         """Starts the form in the current channel.
@@ -204,21 +216,8 @@ class Form(object):
 
         Returns
         -------
-        dict
-            A dictionary containing each question and its data.
-            Example:
-            ::
-
-            {'Key Specified':{
-                    'res':'answer goes here',
-                    'type':'input validation type'
-                    'question':'Question here'
-                },
-            'Next Key Specified':{
-                'res':'answer goes here',
-                'type':'input validation type'
-                'question':'Question here'
-            }
+        FormResponse
+            An object containing all of your keys as attributes.
         """
         elist = []
 
@@ -227,7 +226,7 @@ class Form(object):
 
         qlist = []
         for n, q in enumerate(self._questions.values()):
-            embed=discord.Embed(description=q['question'],color=self.color)
+            embed=discord.Embed(description=q['question'],color=self._color)
 
             embed.set_author(name=f"{self.title}: {n+1}/{len(self._questions)}",icon_url=self._bot.user.avatar_url)
 
@@ -240,6 +239,8 @@ class Form(object):
         prompt = None
 
         for embed in elist:
+            ot = self._tries
+            self._tries = ot
             if self.editanddelete:
                 if not prompt:
                     prompt = await self._ctx.channel.send(embed=embed)
@@ -277,16 +278,18 @@ class Form(object):
                             break
                         else:
                             self._tries -= 1
-                            await channel.send(self._retrymsg+f" You have `{self._tries}` remaining.",delete_after=5)
+                            await channel.send(self._retrymsg+f" You have `{self._tries}` remaining.",delete_after=3)
                             msg = await self._bot.wait_for('message',check=check,timeout=self.timeout)
                             ans = msg.content
                             if self.editanddelete:
                                 await msg.delete()
+                else:
+                    self._questions[key] = ans
             else:
-                self._questions[question] = ans
+                self._questions[key] = ans
         for i in self._questions.keys():
             self._questions[i] = self._questions[i]
-        return self._questions
+        return FormResponse(self._questions)
 
 class InvalidColor(Exception):
     pass
